@@ -1,9 +1,7 @@
 // SPDX-FileCopyrightText: 2023 Carl Schwan <carl@carlschwan.eu>
 // SPDX-License-Identifier: LGPL-2.1-or-later
 
-#include "preferences.h"
-
-#include "utils.h"
+#include "account/preferences.h"
 
 Preferences::Preferences(AbstractAccount *account)
     : QObject(account)
@@ -18,7 +16,7 @@ Preferences::Preferences(AbstractAccount *account)
             }
 
             m_defaultSensitive = obj[QStringLiteral("posting:default:sensitive")].toBool();
-            m_defaultVisibility = stringToVisibility(obj[QStringLiteral("posting:default:visibility")].toString());
+            m_defaultVisibility = Post::stringToVisibility(obj[QStringLiteral("posting:default:visibility")].toString());
             m_extendSpoiler = obj[QStringLiteral("reading:expand:spoilers")].toBool();
             m_extendMedia = obj[QStringLiteral("reading:expand:media")].toString();
             Q_EMIT defaultVisibilityChanged();
@@ -44,7 +42,7 @@ void Preferences::setDefaultVisibility(Post::Visibility visibility)
     m_defaultVisibility = visibility;
     Q_EMIT defaultVisibilityChanged();
 
-    setPreferencesField(QStringLiteral("source[privacy]"), visibilityToString(visibility));
+    setPreferencesField(QStringLiteral("source[privacy]"), Post::visibilityToString(visibility));
 }
 
 bool Preferences::defaultSensitive() const
