@@ -1,10 +1,9 @@
 // SPDX-FileCopyrightText: 2023 Rishi Kumar <rsi.dev17@gmail.com>
 // SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
-#include "emailblocktoolmodel.h"
+#include "admin/emailblocktoolmodel.h"
 
-#include "abstractaccount.h"
-#include "accountmanager.h"
+#include "account/accountmanager.h"
 
 EmailBlockToolModel::EmailBlockToolModel(QObject *parent)
     : QAbstractListModel(parent)
