@@ -1,9 +1,9 @@
 // SPDX-FileCopyrightText: 2021 Carl Schwan <carlschwan@kde.org>
 // SPDX-License-Identifier: GPL-3.0-or-later
 
-#include "notificationmodel.h"
+#include "notification/notificationmodel.h"
 
-#include "abstractaccount.h"
+#include "account/abstractaccount.h"
 
 #include <KLocalizedString>
 
