@@ -2,7 +2,7 @@
 // SPDX-FileCopyrightText: 2021 Carl Schwan <carlschwan@kde.org>
 // SPDX-License-Identifier: GPL-3.0-only
 
-#include "threadmodel.h"
+#include "timeline/threadmodel.h"
 
 #include <KLocalizedString>
 
@@ -16,8 +16,20 @@ ThreadModel::ThreadModel(QObject *parent)
 
 QVariant ThreadModel::data(const QModelIndex &index, int role) const
 {
+    if (!index.isValid()) {
+        return {};
+    }
+
     if (role == SelectedRole) {
         return m_postId == TimelineModel::data(index, IdRole).toString();
+    } else if (role == IsThreadReplyRole) {
+        // This prevents ancestors from being accidentally considered
+        const bool isReplyAfterRootPost = index.row() > m_rootPostIndex;
+        const bool isReplyToRootPost = m_postId != m_timeline[index.row()]->inReplyTo();
+
+        return isReplyAfterRootPost && isReplyToRootPost;
+    } else if (role == IsLastThreadReplyRole) {
+        return !data(ThreadModel::index(index.row() + 1, index.column()), IsThreadReplyRole).toBool();
     }
 
     return TimelineModel::data(index, role);
@@ -44,6 +56,11 @@ void ThreadModel::setPostId(const QString &postId)
     fillTimeline();
 }
 
+QString ThreadModel::postUrl() const
+{
+    return m_postUrl;
+}
+
 void ThreadModel::fillTimeline(const QString &fromId)
 {
     Q_UNUSED(fromId)
@@ -79,14 +96,22 @@ void ThreadModel::fillTimeline(const QString &fromId)
         auto ancestors = obj["ancestors"_L1].toArray().toVariantList();
         std::reverse(ancestors.begin(), ancestors.end());
 
+        const auto descendents = obj["descendants"_L1].toArray();
+
+        // If the root post has a non-zero reply count but no context from the server, it's possible that some replies are not available to us.
+        if (descendents.isEmpty() && thread->front()->repliesCount() != 0) {
+            m_hasHiddenReplies = true;
+            Q_EMIT hasHiddenRepliesChanged();
+        }
+
+        m_rootPostIndex = ancestors.size();
+
         for (const auto &ancestor : ancestors) {
             if (ancestor.canConvert<QJsonObject>() || ancestor.canConvert<QVariantMap>()) {
                 thread->push_front(new Post(m_account, ancestor.toJsonObject(), this));
             }
         }
 
-        const auto descendents = obj["descendants"_L1].toArray();
-
         for (const auto &descendent : descendents) {
             if (!descendent.isObject()) {
                 continue;
@@ -110,6 +135,10 @@ void ThreadModel::fillTimeline(const QString &fromId)
             return;
         }
         thread->push_front(new Post(m_account, obj, this));
+
+        m_postUrl = thread->front()->url().toString();
+        Q_EMIT postUrlChanged();
+
         m_account->get(contextUrl, true, this, onFetchContext, handleError);
     };
 
@@ -147,4 +176,9 @@ void ThreadModel::refresh()
     fillTimeline();
 }
 
+bool ThreadModel::hasHiddenReplies() const
+{
+    return m_hasHiddenReplies;
+}
+
 #include "moc_threadmodel.cpp"
\ No newline at end of file
